#!/usr/bin/env python
#coding=utf-8

import onelab, sys

# we work in the directory where the script is located
workdir = onelab.path(__file__) 

OL = onelab.client()

# Display the geometry in the GUI
OL.openProject(onelab.path(__file__, 'cryo.geo'))

# Check for Onelab parameters in the .geo file
# Gmsh is called with OL.run because it is native
OL.run('mesher', 'gmsh - ' +  onelab.path(__file__, 'cryo.geo'),'')

# Onelab parameters defined in 'cryo.geo' now accessible with OL.get
print('Model radius = %g' % OL.getNumber('Parameters/1Geometry/L'))

# Define additional Onelab parameters
Tcold = OL.defineNumber('Parameters/Elmer/2Tcold', value=77, 
	label='Applied temperature [K]')
NumStep = OL.defineNumber('Elmer/3NumStep', value=50, 
	label='Number of time steps')
TimeStep = OL.defineNumber('Elmer/4TimeStep', value=0.1, 
	label='Time step [s]')

OL.preProcess(onelab.path(__file__, 'cryo.sif.ol'))

OL.defineNumber('Solution/tmin', label='Time of min. [s]',
	attributes={'Highlight':'Coral'})
OL.defineNumber('Solution/fmin', label='Min. of obj. fct',
	attributes={'Highlight':'Coral'})

if OL.action == 'check' :
   exit(1)

   
OL.run('mesher', 'gmsh - ' +  onelab.path(__file__, 'cryo.geo'),'-3')
OL.mergeFile(onelab.path(__file__, 'cryo.msh'))

# Nonnative clients are called with OL.call
OL.call('ElmerGrid 14 2 cryo.msh -out mesh', rundir=workdir)
OL.call('ElmerSolver cryo.sif', rundir=workdir)

OL.mergeFile(onelab.path(__file__, 'solution.pos'))

OL.call('gmsh solution.pos script.opt -', rundir=workdir)

tmin = onelab.extract(onelab.path(__file__, 'fmax.txt'), -1, 2)
fmin = onelab.extract(onelab.path(__file__, 'fmax.txt'), -1, 8)

OL.addNumberChoice('Solution/fmin', fmin)
OL.addNumberChoice('Solution/tmin', tmin)


if not OL.batch:
    OL.preProcess(onelab.path(__file__, 'f.plt.ol'))
    OL.call('gnuplot f.plt', rundir=workdir)
    OL.call('evince f.pdf', rundir=workdir)
else:
    sys.stderr.write('%s: fmin = %12.5e (%12.5e)\n' %
                     (__file__,fmin, 9.916561075116076e-07))
    





